using SCS.SCSSolver
# using Mosek
# using CSDP
# using SDPA

using Nemo

using PropertyT
using Groups

function main(GROUP, parsed_args)

   radius = parsed_args["radius"]
   tol = parsed_args["tol"]
   iterations = parsed_args["iterations"]
   upper_bound = parsed_args["upper-bound"]

   name, N = GROUP.groupname(parsed_args)
   G, S = GROUP.generatingset(parsed_args)
   autS = GROUP.autS(parsed_args)

   name = "$(name)_r$radius"
   isdir(name) || mkdir(name)

   logger = PropertyT.setup_logging(joinpath(name, "$(upper_bound)"))

   info(logger, "Group:       $name")
   info(logger, "Iterations:  $iterations")
   info(logger, "Precision:   $tol")
   info(logger, "Upper bound: $upper_bound")
   info(logger, "Threads:     $(Threads.nthreads())")
   info(logger, "Workers:     $(workers())")
   info(logger, G)
   info(logger, "Symmetric generating set of size $(length(S))")
   # info(logger, S)

   solver = SCSSolver(eps=tol, max_iters=iterations, linearsolver=SCS.Direct, alpha=1.9, acceleration_lookback=1)

   # solver = Mosek.MosekSolver(
   #    MSK_DPAR_INTPNT_CO_TOL_REL_GAP=tol,
   #    MSK_IPAR_INTPNT_MAX_ITERATIONS=iterations,
   #    QUIET=false)

   # solver = CSDP.CSDPSolver(axtol=tol, atytol=tol, objtol=tol, minstepp=tol*10.0^-1, minstepd=tol*10.0^-1)

   # solver = SDPA.SDPASolver(epsilonStar=tol, epsilonDash=tol)


   sett = Settings(name, N, G, S, autS, radius, solver, upper_bound, tol, true)

   PropertyT.check_property_T(sett)
end
